VOOZH about

URL: https://bugs.amule.org/view.php?id=1308

⇱ 0001308: please use xdg-open as default player - aMule Bug Tracker


Anonymous | Login | Signup for a new account2026-06-28 23:32 CEST👁 RSS
My View | View Issues | Change Log | Roadmap

View Issue Details Jump to Notes ] Issue History ] Print ]
IDProjectCategoryView StatusDate SubmittedLast Update
0001308aMuleFeature Requestpublic2008-04-22 14:582008-08-13 17:01
Reporterrmh
Assigned ToWuischke
PrioritynormalSeverityfeatureReproducibilityalways
StatusresolvedResolutionwon't fix
PlatformOSOS Version
Product VersionSVN
Target VersionFixed in Version
Summary0001308: please use xdg-open as default player
Descriptionxdg-open would be a natural fit as the default player, since it automatically selects whatever player has been selected as default in users' desktop environment.
TagsNo tags attached.
Fixed in Revision
Operating SystemDebian GNU/Linux
👁 diff file icon
 xdg-open.diff [^] (2,054 bytes) 2008-04-22 14:58 [Show Content] [Hide Content]
diff -ur amule-2.2.0~20080309/src/muuli_wdr.cpp amule-2.2.0~20080309.new/src/muuli_wdr.cpp
--- amule-2.2.0~20080309/src/muuli_wdr.cpp	2008-01-21 23:31:23.000000000 +0100
+++ amule-2.2.0~20080309.new/src/muuli_wdr.cpp	2008-04-22 13:58:35.000000000 +0200
@@ -2210,7 +2210,7 @@
 
 wxBoxSizer *item19 = new wxBoxSizer( wxHORIZONTAL );
 
- CMuleTextCtrl *item20 = new CMuleTextCtrl( parent, IDC_VIDEOPLAYER, wxT("mplayer -idx"), wxDefaultPosition, wxSize(80,-1), 0 );
+ CMuleTextCtrl *item20 = new CMuleTextCtrl( parent, IDC_VIDEOPLAYER, wxT("xdg-open"), wxDefaultPosition, wxSize(80,-1), 0 );
 item19->Add( item20, 1, wxGROW|wxALIGN_CENTER_HORIZONTAL, 5 );
 
 wxButton *item21 = new wxButton( parent, IDC_BROWSEV, _("Browse"), wxDefaultPosition, wxDefaultSize, 0 );

 Relationships
diff -ur amule-2.2.0~20080309/src/DownloadListCtrl.cpp amule-2.2.0~20080309.new/src/DownloadListCtrl.cpp
--- amule-2.2.0~20080309/src/DownloadListCtrl.cpp	2008-02-21 19:00:45.000000000 +0100
+++ amule-2.2.0~20080309.new/src/DownloadListCtrl.cpp	2008-04-22 13:58:21.000000000 +0200
@@ -2215,16 +2215,16 @@
 void CDownloadListCtrl::PreviewFile(CPartFile* file)
 {
 	wxString command;
 	// If no player set in preferences, use mplayer.
 	// And please, do a warning also :P
 	if (thePrefs::GetVideoPlayer().IsEmpty()) {
 		wxMessageBox(_(
 			"Please set your preferred video player on preferences.\n"
-			"Meanwhile, aMule will attempt to use mplayer and you will get this warning on every preview"),
+			"Meanwhile, aMule will attempt to use xdg-open and you will get this warning on every preview"),
 			_("File preview"), wxOK, this);
 		// Since newer versions for some reason mplayer does not automatically
 		// select video output device and needs a parameter, go figure...
-		command = wxT("xterm -T \"aMule Preview\" -iconic -e mplayer ") QUOTE wxT("$file") QUOTE;
+		command = wxT("xterm -T \"aMule Preview\" -iconic -e xdg-open ") QUOTE wxT("$file") QUOTE;
 	} else {
 		command = thePrefs::GetVideoPlayer();
 	}
@@ -2215,16 +2215,16 @@
 {
 	wxString command;
-	// If no player set in preferences, use mplayer.
+	// If no player set in preferences, use xdg-open.
 	// And please, do a warning also :P
 	if (thePrefs::GetVideoPlayer().IsEmpty()) {